-- ============================================================
--   Table: GSO_TIPOFAIXA                                      
-- ============================================================
CREATE TABLE GSO_TIPOFAIXA
(
    NRTIPOFAIXA       NUMBER                 NOT NULL,
    DSTIPOFAIXA       VARCHAR2(100)          NOT NULL,
    NRORG             NUMBER 	             DEFAULT         SYS_CONTEXT('nrorg_ctx','nrorg') NOT NULL,
    IDATIVO           VARCHAR2(1)            DEFAULT 'S'        NOT NULL
      CONSTRAINT CKC_IDATIVO_GSO_TIPOFAIXA CHECK (IDATIVO IN ('S','N')),
    DTINCLUSAO        DATE                   			        NULL,
    DTULTATU          DATE                   			        NULL,
    NRORGINCLUSAO     NUMBER                 DEFAULT 1 			NULL,
    CDOPERINCLUSAO    VARCHAR2(12)           DEFAULT '1' 		NULL,
    NRORGULTATU       NUMBER                 DEFAULT 1 			NULL,
    CDOPERULTATU      VARCHAR2(12)           DEFAULT '1',	
        CONSTRAINT PK_GSO_TIPOFAIXA PRIMARY KEY (NRTIPOFAIXA)
)
/

-- ============================================================
--   Table: GPE_OCUPACAOM                                      
-- ============================================================
ALTER TABLE GPE_OCUPACAOM ADD NROCUPACAOMSUP NUMBER NULL
/
CREATE INDEX HCM00057_FK ON GPE_OCUPACAOM (NROCUPACAOMSUP ASC)
/

-- ============================================================
--   Table: GSO_FAIXA                                          
-- ============================================================
CREATE TABLE GSO_FAIXA
(
    NRFAIXA              NUMBER                 NOT NULL,
    NRTIPOFAIXA          NUMBER                 NOT NULL,
    DSFAIXA              VARCHAR2(100)          NOT NULL,
    NRORDEMFAIXA         NUMBER                 NOT NULL,
    NRORG                NUMBER 	            DEFAULT         SYS_CONTEXT('nrorg_ctx','nrorg') NOT NULL,
    IDATIVO              VARCHAR2(1)            DEFAULT 'S'        NOT NULL
      CONSTRAINT CKC_IDATIVO_GSO_FAIXA CHECK (IDATIVO IN ('S','N')),
    DTINCLUSAO           DATE                   			       NULL,
    DTULTATU             DATE                   			       NULL,
    NRORGINCLUSAO        NUMBER                 DEFAULT 1 		   NULL,
    CDOPERINCLUSAO       VARCHAR2(12)           DEFAULT '1' 	   NULL,
    NRORGULTATU          NUMBER                 DEFAULT 1 		   NULL,
    CDOPERULTATU         VARCHAR2(12)           DEFAULT '1',			
    CONSTRAINT PK_GSO_FAIXA PRIMARY KEY (NRFAIXA)
)
/
CREATE INDEX HCM00058_FK  ON GSO_FAIXA (NRTIPOFAIXA ASC)
/

-- ============================================================
--   Table: GSO_PONTUACAOCUPA                                  
-- ============================================================
CREATE TABLE GSO_PONTUACAOCUPA
(
    NRPONTUACAOCUPA      NUMBER                 NOT NULL,
    NROCUPACAOM          NUMBER                 NOT NULL,
    DSTIPOPONTUACAO      VARCHAR2(20)           NOT NULL,
    VRPONTUACAO          FLOAT                  NOT NULL,
    NRORG                NUMBER 	            DEFAULT         SYS_CONTEXT('nrorg_ctx','nrorg') NOT NULL,
    IDATIVO              VARCHAR2(1)            DEFAULT 'S'         NOT NULL
      CONSTRAINT CKC_IDATIVO_GSO_PONTUACAOCUPA CHECK (IDATIVO IN ('S','N')),
    DTINCLUSAO           DATE                   			        NULL,
    DTULTATU             DATE                   			        NULL,
    NRORGINCLUSAO        NUMBER                 DEFAULT 1 			NULL,
    CDOPERINCLUSAO       VARCHAR2(12)           DEFAULT '1' 		NULL,
    NRORGULTATU          NUMBER                 DEFAULT 1 			NULL,
    CDOPERULTATU         VARCHAR2(12)           DEFAULT '1',				
    CONSTRAINT PK_GSO_PONTUACAOCUPA PRIMARY KEY (NRPONTUACAOCUPA)
)
/
CREATE INDEX HCM00059_FK ON GSO_PONTUACAOCUPA (NROCUPACAOM ASC)
/

-- ============================================================
--   Table: GSO_FORMACAOCUPA                                   
-- ============================================================
CREATE TABLE GSO_FORMACAOCUPA
(
    NRFORMACAOCUPA       NUMBER                 NOT NULL,
    NROCUPACAOM          NUMBER                 NOT NULL,
    NRAREAFORMACAO       NUMBER                 NOT NULL,
    CDIDIOMA             VARCHAR2(10)           NULL    ,
    IDNVIDIOMA           VARCHAR2(10)           NULL    ,
    NRORG                NUMBER 	            DEFAULT         SYS_CONTEXT('nrorg_ctx','nrorg') NOT NULL,
    IDATIVO              VARCHAR2(1)            DEFAULT 'S'         NOT NULL
      CONSTRAINT CKC_IDATIVO_GSO_FORMOCUPA CHECK (IDATIVO IN ('S','N')),
    DTINCLUSAO           DATE                   			        NULL,
    DTULTATU             DATE                   			        NULL,
    NRORGINCLUSAO        NUMBER                 DEFAULT 1 			NULL,
    CDOPERINCLUSAO       VARCHAR2(12)           DEFAULT '1' 		NULL,
    NRORGULTATU          NUMBER                 DEFAULT 1 			NULL,
    CDOPERULTATU         VARCHAR2(12)           DEFAULT '1',						
        CONSTRAINT PK_GSO_FORMACAOCUPA PRIMARY KEY (NRFORMACAOCUPA)
)
/
CREATE INDEX HCM00060_FK ON GSO_FORMACAOCUPA (NROCUPACAOM ASC)
/
CREATE INDEX HCM00061_FK ON GSO_FORMACAOCUPA (NRAREAFORMACAO ASC)
/
ALTER TABLE GSO_FORMACAOCUPA ADD (NRTIPOFORMACAO NUMBER, NRCURSO NUMBER, DSCURSO VARCHAR2(100))
/	 
ALTER TABLE GSO_FORMACAOCUPA MODIFY (NRAREAFORMACAO NUMBER NULL)
/


-- ============================================================
--   Table: GSO_AVALOCUPACAO                                   
-- ============================================================
CREATE TABLE GSO_AVALOCUPACAO
(
    NRAVALOCUPACAO	     NUMBER                 NOT NULL,  
    NROCUPACAOM          NUMBER                 NOT NULL,
    NRAVALIACAO          NUMBER                 NOT NULL,
    NRORG                NUMBER 	            DEFAULT         SYS_CONTEXT('nrorg_ctx','nrorg') NOT NULL,
    IDATIVO              VARCHAR2(1)            DEFAULT 'S'         NOT NULL
      CONSTRAINT CKC_IDATIVO_GSO_AVALOCUPACAO CHECK (IDATIVO IN ('S','N')),
    DTINCLUSAO           DATE                   			        NULL,
    DTULTATU             DATE                   			        NULL,
    NRORGINCLUSAO        NUMBER                 DEFAULT 1 			NULL,
    CDOPERINCLUSAO       VARCHAR2(12)           DEFAULT '1' 		NULL,
    NRORGULTATU          NUMBER                 DEFAULT 1 			NULL,
    CDOPERULTATU         VARCHAR2(12)           DEFAULT '1',	 
        CONSTRAINT PK_GSO_AVALOCUPACAO PRIMARY KEY (NRAVALOCUPACAO)	
)
/
CREATE INDEX HCM00062_FK ON GSO_AVALOCUPACAO (NROCUPACAOM ASC)
/
CREATE INDEX HCM00063_FK ON GSO_AVALOCUPACAO (NRAVALIACAO ASC)
/

-- ============================================================
--   Table: GSO_TABELASALARIAL                                 
-- ============================================================
CREATE TABLE GSO_TABELASALARIAL
(
    NRTABELASALARIAL     NUMBER                 NOT NULL,
    NRFAIXA              NUMBER                 NOT NULL,
    NROCUPACAOM          NUMBER                 NOT NULL,
    DSTABELASALARIAL     VARCHAR2(100)          NOT NULL,
    DTINIVIGTABSALARIAL  DATE                   NOT NULL,
    DTFIMVIGTABSALARIAL  DATE                   NULL    ,
    DTBASETABSALARIAL    DATE                   NOT NULL,
    VRPISOTABSALARIAL    FLOAT                  NULL    ,
    VRTETOTABSALARIAL    FLOAT                  NULL    ,
    VR1SALTABELA         FLOAT                  NULL    ,
    VR2SALTABELA         FLOAT                  NULL    ,
    VR3SALTABELA         FLOAT                  NULL    ,
    VR4SALTABELA         FLOAT                  NULL    ,
    VR5SALTABELA         FLOAT                  NULL    ,
    VR6SALTABELA         FLOAT                  NULL    ,
    VR7SALTABELA         FLOAT                  NULL    ,
    VR8SALTABELA         FLOAT                  NULL    ,
    VR9SALTABELA         FLOAT                  NULL    ,
    VR10SALTABELA        FLOAT                  NULL    ,
    NRORG                NUMBER 	            DEFAULT         SYS_CONTEXT('nrorg_ctx','nrorg') NOT NULL,
    IDATIVO              VARCHAR2(1)            DEFAULT 'S'         NOT NULL
      CONSTRAINT CKC_IDATIVO_GSO_TABELASALARIAL CHECK (IDATIVO IN ('S','N')),
    DTINCLUSAO           DATE                   			        NULL,
    DTULTATU             DATE                   			        NULL,
    NRORGINCLUSAO        NUMBER                 DEFAULT 1 			NULL,
    CDOPERINCLUSAO       VARCHAR2(12)           DEFAULT '1' 		NULL,
    NRORGULTATU          NUMBER                 DEFAULT 1 			NULL,
    CDOPERULTATU         VARCHAR2(12)           DEFAULT '1',	 
        CONSTRAINT GSO_TABELASALARIAL_PK PRIMARY KEY (NRTABELASALARIAL)
)
/
CREATE INDEX HCM00064_FK ON GSO_TABELASALARIAL (NRFAIXA ASC)
/
CREATE INDEX HCM00065_FK ON GSO_TABELASALARIAL (NROCUPACAOM ASC)
/
ALTER TABLE GSO_TABELASALARIAL ADD NRESTRUTSIND NUMBER
/

-- ============================================================
--   Table: GPE_VINCULOH                                       
-- ============================================================
ALTER TABLE GPE_VINCULOH ADD NRFAIXA NUMBER NULL
/
CREATE INDEX HCM00066_FK ON GPE_VINCULOH (NRFAIXA ASC)
/

-- ============================================================
--   Table: GPE_ALTEOCUPACAO                                   
-- ============================================================
ALTER TABLE GPE_ALTEOCUPACAO ADD NRFAIXA NUMBER NULL
/
CREATE INDEX HCM00067_FK ON GPE_ALTEOCUPACAO (NRFAIXA ASC)
/

-- ============================================================
--   Table: GPE_OCUPACAOH                                       
-- ============================================================
ALTER TABLE GPE_OCUPACAOH ADD DSOBJETIVOCARGO    VARCHAR2(4000)    NULL
/
ALTER TABLE GPE_OCUPACAOH ADD DSATIVIDADESCARGO  VARCHAR2(4000)    NULL
/
ALTER TABLE GPE_OCUPACAOH ADD DSCONDTRABALHO     VARCHAR2(4000)    NULL
/
ALTER TABLE GPE_OCUPACAOH ADD NRTEMPOEXPANO      NUMBER            NULL
/
ALTER TABLE GPE_OCUPACAOH ADD NRTEMPOEXPMES      NUMBER            NULL
/
ALTER TABLE GSO_FAIXA
    ADD CONSTRAINT FKHCM00068_GSO_FAIXA FOREIGN KEY  (NRTIPOFAIXA)
       REFERENCES GSO_TIPOFAIXA (NRTIPOFAIXA)
/
CREATE INDEX HCM00068_FK ON GSO_FAIXA (NRTIPOFAIXA ASC)
/
ALTER TABLE GSO_PONTUACAOCUPA
    ADD CONSTRAINT FKHCM00069_GSO_PONTUOCUPA FOREIGN KEY  (NROCUPACAOM)
       REFERENCES GPE_OCUPACAOM (NROCUPACAOM)
/
CREATE INDEX HCM00069_FK ON GSO_PONTUACAOCUPA (NROCUPACAOM ASC)
/
ALTER TABLE GSO_FORMACAOCUPA
    ADD CONSTRAINT FKHCM00070_GSO_FORMCUPA FOREIGN KEY  (NROCUPACAOM)
       REFERENCES GPE_OCUPACAOM (NROCUPACAOM)
/
CREATE INDEX HCM00070_FK ON GSO_FORMACAOCUPA (NROCUPACAOM ASC)
/
ALTER TABLE GSO_FORMACAOCUPA
    ADD CONSTRAINT FKHCM00071_GSO_FORMCUPA FOREIGN KEY  (NRAREAFORMACAO)
       REFERENCES DES_AREAFORMACAO (NRAREAFORMACAO)
/
CREATE INDEX HCM00071_FK ON GSO_FORMACAOCUPA (NRAREAFORMACAO ASC)
/
ALTER TABLE GSO_AVALOCUPACAO
    ADD CONSTRAINT FKHCM00072_GSO_AVALOCUPA FOREIGN KEY  (NROCUPACAOM)
       REFERENCES GPE_OCUPACAOM (NROCUPACAOM)
/
CREATE INDEX HCM00072_FK ON GSO_AVALOCUPACAO (NROCUPACAOM ASC)
/
ALTER TABLE GSO_TABELASALARIAL
    ADD CONSTRAINT FKHCM00073_GSO_TABSALARI FOREIGN KEY  (NRFAIXA)
       REFERENCES GSO_FAIXA (NRFAIXA)
/
CREATE INDEX HCM00073_FK ON GSO_TABELASALARIAL (NRFAIXA ASC)
/
ALTER TABLE GSO_TABELASALARIAL
    ADD CONSTRAINT FKHCM00074_GSO_TABSALARI FOREIGN KEY  (NROCUPACAOM)
       REFERENCES GPE_OCUPACAOM (NROCUPACAOM)
/
CREATE INDEX HCM00074_FK ON GSO_TABELASALARIAL (NROCUPACAOM ASC)
/
ALTER TABLE GPE_VINCULOH
    ADD CONSTRAINT FKHCM00075_GPE_VINCH FOREIGN KEY  (NRFAIXA)
       REFERENCES GSO_FAIXA (NRFAIXA)
/
CREATE INDEX HCM00075_FK ON GPE_VINCULOH (NRFAIXA ASC)
/
ALTER TABLE GPE_ALTEOCUPACAO
    ADD CONSTRAINT FKHCM00076_GPE_ALTOCUPA FOREIGN KEY  (NRFAIXA)
       REFERENCES GSO_FAIXA (NRFAIXA)
/
CREATE INDEX HCM00076_FK ON GPE_ALTEOCUPACAO (NRFAIXA ASC)